8146620: CodelistTest.java fails with "Test failed on: jdk.internal.misc.Unsafe.getUnsafe()Ljdk/internal/misc/Unsafe;"
authorjbachorik
Tue, 12 Jan 2016 11:11:21 +0100
changeset 35472 cd54a457564e
parent 35471 deb38c83d759
child 35474 8333d76c7fee
child 35475 c5e6cb508475
8146620: CodelistTest.java fails with "Test failed on: jdk.internal.misc.Unsafe.getUnsafe()Ljdk/internal/misc/Unsafe;" Reviewed-by: sla
hotspot/test/serviceability/dcmd/compiler/CodelistTest.java
--- a/hotspot/test/serviceability/dcmd/compiler/CodelistTest.java	Fri Jan 08 08:51:18 2016 -0800
+++ b/hotspot/test/serviceability/dcmd/compiler/CodelistTest.java	Tue Jan 12 11:11:21 2016 +0100
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014, 2015, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2014, 2016, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -80,7 +80,8 @@
             // int compileLevel = Integer.parseInt(parts[1]);
             String methodPrintedInLogFormat = parts[2];
 
             // skip inits, clinits and methodHandles - they can not be reflected
             if (methodPrintedInLogFormat.contains("<init>")) {
                 continue;
             }
@@ -93,6 +94,9 @@
             if (methodPrintedInLogFormat.contains("sun.misc.Unsafe.getUnsafe")) {
                 continue;
             }
+            if (methodPrintedInLogFormat.contains("jdk.internal.misc.Unsafe.getUnsafe")) {
+                continue;
+            }
 
             MethodIdentifierParser mf = new MethodIdentifierParser(methodPrintedInLogFormat);
             Method m = null;
@@ -80,7 +80,8 @@
             String methodPrintedInLogFormat = parts[2];
 
-            // skip inits, clinits and methodHandles - they can not be reflected
+            // skip inits, clinits, methodHandles and getUnsafe -
+            // they can not be reflected
             if (methodPrintedInLogFormat.contains("<init>")) {
                 continue;